@@ -18,8 +18,10 @@
 #'
 #' cumulative_i <- cumulate(i)
 #' cumulative_i
-#' @importFrom dplyr .data
+#'
+#' @import data.table
 #' @export
+#'
 #' @rdname cumulate
 cumulate <- function(x) {
   UseMethod("cumulate", x)
@@ -33,24 +35,32 @@ cumulate.default <- function(x) {
 }
 
 
-#' @importFrom dplyr grouped_df mutate ungroup
 #' @export
 #' @rdname cumulate
 cumulate.incidence2 <- function(x) {
+
+  # due to NSE notes in R CMD check
+  ..count_var <- NULL
+
   is_cumulate <- attr(x, "cumulative")
   if (is_cumulate) {
     stop("x is already a cumulative incidence")
   }
-  out <- x
+
   groups <- get_group_names(x)
-  count_var <- get_counts_name(x)
+  count_var <- get_count_names(x)
+
+  out <- as.data.table(x)
   if (!is.null(groups)) {
-    out <- grouped_df(out, groups)
+    out[, (count_var) := lapply(.SD, cumsum), keyby = groups, .SDcols = count_var]
+  } else {
+    out[, (count_var) := lapply(.SD, cumsum), .SDcols = count_var]
   }
-  out <- mutate(out, count = cumsum(.data[[count_var]]))
-  out <- ungroup(out)
-  names(out) <- names(x)
+  setDF(out)
+
+  nms <- names(out)
   attributes(out) <- attributes(x)
+  names(out) <- nms
   attr(out, "cumulative") <- TRUE
   out
 }
