@@ -9,6 +9,7 @@ knitr::opts_chunk$set(
 
 ## ----regroup------------------------------------------------------------------
 library(outbreaks)
+library(dplyr)
 library(incidence2)
 
 # load data
@@ -17,7 +18,7 @@ dat <- ebola_sim_clean$linelist
 # generate the incidence object with 3 groups
 inci <- incidence(dat, date_index = date_of_onset,
                   groups = c(gender, hospital, outcome),
-                  interval = "1 week")
+                  interval = "week")
 inci
 
 # regroup to just two groups
@@ -28,8 +29,14 @@ inci %>% regroup()
 
 ## ----cumulate-----------------------------------------------------------------
 inci %>% 
+  regroup(hospital) %>% 
   cumulate() %>% 
-  facet_plot(facet = hospital, n_breaks = 2)
+  facet_plot(n_breaks = 4)
+
+## ----keep---------------------------------------------------------------------
+inci %>% keep_first(3)
+
+inci %>% keep_last(3)
 
 ## ----tidyverse----------------------------------------------------------------
 library(dplyr)
@@ -39,65 +46,28 @@ inci <-
   dat %>%
   incidence(
     date_index = date_of_onset,
-    interval = "2 weeks",
-    first_date = "2014-05-20",
-    last_date = "2014-06-10",
+    interval = "week",
     groups = c(hospital, gender)
   )
 
 # filtering preserves class
-x <-
-    inci %>%
-    filter(gender == "f", hospital == "Rokupa Hospital")
-x
-identical(class(x), class(inci))
+inci %>%  filter(gender == "f", hospital == "Rokupa Hospital")
 
 # slice operations preserve class
-x <-
-    inci %>%
-    slice_sample(n = 10)
-x
-identical(class(x), class(inci))
+inci %>% slice_sample(n = 10)
 
-inci %>%
-  slice(1, 5, 10) %>%
-  class() %>% 
-  identical(class(inci))
+inci %>%  slice(1, 5, 10)
 
 # mutate preserve class
-x <-
-    inci %>%
-    mutate(future = bin_date + 999)
-x
-identical(class(x), class(inci))
+inci %>%  mutate(future = date_index + 999)
 
 # rename preserve class
-x <-
-  inci %>%
-  rename(left_bin = bin_date)
-identical(class(x), class(inci))
+inci %>%  rename(left_bin = date_index)
+
 
 # select returns a tibble unless all date, count and group variables are preserved
 inci %>% select(-1)
 
-x <-
-    inci %>%
-    select(everything())
-x
-
-# Adding rows that are multiples of 2 weeks will maintain class
-x <-
-    inci %>%
-    slice_head(n = 2) %>%
-    mutate(bin_date = bin_date + 112) %>%
-    bind_rows(inci)
-x
-identical(class(x), class(inci))
+inci %>% select(everything())
 
 
-# Adding rows with dates that are not multiples of 2 weeks drops class
-inci %>%
-  slice_head(n = 2) %>%
-  mutate(bin_date = bin_date + 30) %>%
-  bind_rows(inci)
-
